# ICM20948 9-DOF Accelerometer, Magnetometer and Gyroscope

[![Build Status](https://travis-ci.com/pimoroni/icm20948-python.svg?branch=master)](https://travis-ci.com/pimoroni/icm20948-python)
[![Coverage Status](https://coveralls.io/repos/github/pimoroni/icm20948-python/badge.svg?branch=master)](https://coveralls.io/github/pimoroni/icm20948-python?branch=master)
[![PyPi Package](https://img.shields.io/pypi/v/icm20948.svg)](https://pypi.python.org/pypi/icm20948)
[![Python Versions](https://img.shields.io/pypi/pyversions/icm20948.svg)](https://pypi.python.org/pypi/icm20948)


# Installing

Stable library from PyPi:

* Just run `sudo pip install icm20948`

Latest/development library from GitHub:

* `git clone https://github.com/pimoroni/icm20948-python`
* `cd icm20948-python`
* `sudo ./install.sh`


# Changelog
